Draws grids using frames of characters on a Gameduino display. Requires Gameduino library.

Files at this revision

API Documentation at this revision

Comitter:
RichardE
Date:
Sat Nov 24 17:18:47 2012 +0000
Parent:
1:b5d8f8deafa5
Commit message:
Added GetCharacterCodes method.

Changed in this revision

CharacterNet.h Show annotated file Show diff for this revision Revisions of this file
--- a/CharacterNet.h	Sat Nov 24 12:55:27 2012 +0000
+++ b/CharacterNet.h	Sat Nov 24 17:18:47 2012 +0000
@@ -37,7 +37,7 @@
             CodePosCount            // number of codes, MUST COME LAST
         };
         
         /** Set characters codes to use when drawing.
          * Array must contain CodePosCount items and order of
          * codes is defined by CodePos enumeration.
          * @param codes Array of characters codes to use.
@@ -45,7 +45,14 @@
         void SetCharacterCodes( const UInt8 *codes ) {
             characterCodes = codes;
         }
-         
+
+        /** Get character codes currently in use when drawing.
+         * @param codes Array of characters codes in use.
+         */
+        const UInt8 *GetCharacterCodes( void ) const {
+            return characterCodes;
+        }
+                 
         /** Draw a net of characters.
          * @param gd The Gameduino to draw on.
          * @param xco X coordinate for top left.
@@ -37,7 +37,7 @@
         };
         
-        /** Set characters codes to use when drawing.
+        /** Set character codes to use when drawing.
          * Array must contain CodePosCount items and order of
          * codes is defined by CodePos enumeration.